@@ -1,12 +1,14 @@
 
-def bam_header_generator(orig_header,chrom_size,prog_name,prog_ver,co,format_ver=1.0,sort_type = 'coordinate'):
-	'''generates header section for BAM file'''
+def bam_header_generator(orig_header, chrom_size, prog_name, prog_ver, co, format_ver=1.0, sort_type = 'coordinate'):
+	'''
+	generates header section for BAM file
+	'''
 	bamHeaderLine=orig_header
 	name2id={}
 	id = 0
 	# replace 'HD'
 	bamHeaderLine['HD'] = {'VN':format_ver,'SO':sort_type}
-	
+
 	# replace SQ
 	tmp=[]
 	for ref_name in sorted(chrom_size):
@@ -18,7 +20,7 @@ def bam_header_generator(orig_header,chrom_size,prog_name,prog_ver,co,format_ver
 		bamHeaderLine['PG'] .append( {'ID':prog_name,'VN':prog_ver})
 	else:
 		bamHeaderLine['PG'] = [{'ID':prog_name,'VN':prog_ver}]
-	
+
 	for comment in co:
 		if 'CO' in bamHeaderLine:
 			bamHeaderLine['CO'].append(comment)
